%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1997  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Purpose:
%
%    The FEMBIF package implements piecewise linear simplicial finite
%    elements, a posteriori error estimation, adaptive mesh refinement
%    (quadrasection and bisection), continuation methods, and global
%    inexact-newton methods for nonlinear elliptic equations on arbitrary
%    polyhedral domains in 2D.
%
%    This package solves the following general nonlinear elliptic equation:
%
%       - \nabla \cdot a(x,u,\nabla u) + b(x,u,\nabla u) = f in Omega in R^2,
%
%    with general nonlinear robin boundary conditions:
%
%              n \cdot a(x,u,\nabla u) + c(x,u,\nabla u) = g on \Gamma_N,
%                                                      u = h on \Gamma_D,
%                where \partial \Omega = \Gamma = \Gamma_D \cup \Gamma_N.
%
%    For details, refer to the caltech lecture notes of Michael Holst.
%
% Package files:
%
%    0readme.m   ==> this file
%    0print.sh   ==> print all files
%
%    go.m        ==> main driver; defines mesh, refines, discretizes, solves.
%    mesh.m      ==> mesh and domain definition
%    fu_v.m      ==> nonlinear-linear form
%    dfu_wv.m    ==> nonlinear-bilinear form
%    u_d.m       ==> dirichlet boundary condition
%    u_t.m       ==> analytical (continuous) solution (for testing)
%
%    assem.m     ==> tangent system assembly
%    mastr.m     ==> master element information definitions
%    facetype.m  ==> decode simplex face types
%
%    mark.m      ==> a posteriori error estimation
%    refin.m     ==> adaptive (quadrasection/bisection) mesh refinement
%    getq.m      ==> decode the queue flags
%    putq.m      ==> encode the queue flags
%
%    newton.m    ==> nonlinear solver (global inexact-newton with continuation)
%
%    draw.m      ==> draws a finite element mesh
%    drawf.m     ==> draws a function defined over a finite element mesh
%    mypaus.m    ==> pauses and displays a message
%
% Author:   Michael Holst 050497
%
