function [U,A,F]=newton(VERT, SIMP);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FEMBIF = < Finite Element Methods for Bifurcation >
%% Copyright (C) 1997  Michael Holst
%%
%% This program is free software; you can redistribute it and/or modify it
%% under the terms of the GNU General Public License as published by the Free
%% Software Foundation; either version 2 of the License, or (at your option)
%% any later version.
%%
%% This program is distributed in the hope that it will be useful, but WITHOUT
%% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%% FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%% more details.
%%
%% You should have received a copy of the GNU General Public License along
%% with this program; if not, write to the Free Software Foundation, Inc.,
%% 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%% Typing "help 0license" should list the GNU GPL to the screen.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Prototype:
%
%    [U,A,F]=newton(VERT, SIMP);
%
% Purpose:
%
%    Discretize and solve the nonlinear pde with a newton iteration.
%
% Input:
%
%    (N  = number of vertices in mesh)
%    (L  = number of simplices in mesh)
%
%    VERT = zeros(N,6); vertices, (x,y,z)-coordinates of all vertices
%    SIMP = zeros(L,9); simplices, vertices numbers given counter-clockwise
%
% Output:
%
%    U    = solution to nonlinear problem
%    A    = last jacobian matrix
%    F    = last nonlinear residual vector
%
% Author:   Michael Holst 050497
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% doit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   %%% sizes of things
   [N,six]  = size(VERT);
   [L,nine] = size(SIMP);

   %%% initial FEM solution
   U=zeros(N,1);

   %%% parameters
   parm = zeros(10,1);

   %%% newton iteration
   itmax = 30;
   errtol = 1.0e-5;
   iter = 0;
   done = 0;
   while ((done == 0) & (iter < itmax))
      iter = iter + 1;

      %%% assemble jacobian system
      assKey = 2;
      parm(1) = 1;
      [A,F]=assem(assKey, parm, U, VERT, SIMP);

      %%% initial residual
      if (iter == 1)
         normF = norm(F,2);
         fprintf('NEWTON: iter = %g, ||F(u)|| = %g\n', 0, normF);
      end

      %%% solve jacobian system and correct
      E = A \ F;
      U = U + E;

      %%% nonlinear residual
      assKey = 3;
      parm(1) = 1;
      [A,F]=assem(assKey, parm, U, VERT, SIMP);

      %%% solution quality
      normF = norm(F,2);
      fprintf('NEWTON: iter = %g, ||F(u)|| = %g\n', iter, normF);
      if (normF < errtol)
         done = 1;
      end;
   end

